"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _columnsContainer = _interopRequireDefault(require("./columnsContainer"));

var _indexesContainer = _interopRequireDefault(require("./indexesContainer"));

var _column = _interopRequireDefault(require("./column"));

var _tableIndex = _interopRequireDefault(require("./tableIndex"));

var _driver = _interopRequireDefault(require("./driver"));

class Table {
  constructor() {
    this.columnsContainer = this.createColumnsContainer();
    this.indexesContainer = this.createIndexesContainer();
  }

  column(name) {
    return this.getColumnsContainer().column(name);
  }

  index(name = "") {
    return this.getIndexesContainer().index(name);
  }

  createColumnsContainer() {
    const setClass = this.getDriver().getColumnsClass();
    return new setClass(this);
  }

  createIndexesContainer() {
    const setClass = this.getDriver().getIndexesClass();
    return new setClass(this);
  }

  getColumnsContainer() {
    return this.columnsContainer;
  }

  getIndexesContainer() {
    return this.indexesContainer;
  }

  getColumn(name) {
    return this.getColumnsContainer().getColumn(name);
  }

  getColumns() {
    return this.getColumnsContainer().getColumns();
  }

  getIndex(name) {
    return this.getIndexesContainer().getIndex(name);
  }

  getIndexes() {
    return this.getIndexesContainer().getIndexes();
  }

  toObject() {
    const json = {
      autoIncrement: this.constructor.getAutoIncrement(),
      name: this.constructor.getName(),
      comment: this.constructor.getComment(),
      engine: this.constructor.getEngine(),
      collate: this.constructor.getCollate(),
      defaultCharset: this.constructor.getDefaultCharset(),
      columns: [],
      indexes: []
    };
    this.getColumns().forEach(column => {
      json.columns.push(column.getObjectValue());
    });
    this.getIndexes().forEach(index => {
      json.indexes.push(index.getObjectValue());
    });
    return json;
  }
  /**
   * Sets table driver.
   * @param driver
   * @returns {Table}
   */


  static setDriver(driver) {
    this.driver = driver;
    return this;
  }
  /**
   * Returns set driver.
   * @returns {Driver}
   */


  static getDriver() {
    return this.driver;
  }
  /**
   * Returns set driver.
   * @returns {Driver}
   */


  getDriver() {
    return this.constructor.driver;
  }

  static setEngine(value) {
    this.engine = value;
    return this;
  }

  static getEngine() {
    return this.engine;
  }

  getEngine() {
    return this.constructor.engine;
  }

  static setDefaultCharset(defaultCharset) {
    this.defaultCharset = defaultCharset;
    return this;
  }

  static getDefaultCharset() {
    return this.defaultCharset;
  }

  getDefaultCharset() {
    return this.constructor.defaultCharset;
  }

  static setCollate(collate) {
    this.collate = collate;
    return this;
  }

  static getCollate() {
    return this.collate;
  }

  getCollate() {
    return this.constructor.collate;
  }

  static setName(name) {
    this.tableName = name;
    return this;
  }

  static getName() {
    return this.tableName;
  }

  getName() {
    return this.constructor.getName();
  }

  static setComment(comment) {
    this.comment = comment;
    return this;
  }

  static getComment() {
    return this.comment;
  }

  getComment() {
    return this.constructor.getComment();
  }

  static setAutoIncrement(autoIncrement) {
    this.autoIncrement = autoIncrement;
    return this;
  }

  static getAutoIncrement() {
    return this.autoIncrement;
  }

  getAutoIncrement() {
    return this.constructor.getAutoIncrement();
  }

  async create(options = {}) {
    const sql = await this.getDriver().create(this, options);

    if (options.returnSQL) {
      return sql;
    }

    return this.getDriver().execute(sql);
  }

  async alter(options = {}) {
    const sql = await this.getDriver().alter(this, options);

    if (options.returnSQL) {
      return sql;
    }

    return this.getDriver().execute(sql);
  }

  async drop(options = {}) {
    const sql = await this.getDriver().drop(this, options);

    if (options.returnSQL) {
      return sql;
    }

    return this.getDriver().execute(sql);
  }

  async truncate(options = {}) {
    const sql = await this.getDriver().truncate(this, options);

    if (options.returnSQL) {
      return sql;
    }

    return this.getDriver().execute(sql);
  }

  async sync(options = {}) {
    const sql = await this.getDriver().sync(this, options);

    if (options.returnSQL) {
      return sql;
    }

    return this.getDriver().execute(sql);
  }

}

Table.engine = "";
Table.tableName = "";
Table.defaultCharset = "";
Table.collate = "";
Table.comment = "";
Table.autoIncrement = 0;
Table.driver = new _driver.default();
var _default = Table;
exports.default = _default;
//# sourceMappingURL=table.js.map